api.permissions.v1.function.test_helpers.function package — Argus-Toolbelt 1.0 documentation

# api.permissions.v1.function.test_helpers.function package

## Submodules

## api.permissions.v1.function.test_helpers.function.get_function_by_id module

`api.permissions.v1.function.test_helpers.function.get_function_by_id.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/permissions/v1/function/w+, respond with HTTP 403

`api.permissions.v1.function.test_helpers.function.get_function_by_id.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/permissions/v1/function/w+, respond with HTTP 404

`api.permissions.v1.function.test_helpers.function.get_function_by_id.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/permissions/v1/function/w+, respond with HTTP 200

`api.permissions.v1.function.test_helpers.function.get_function_by_id.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/permissions/v1/function/w+, respond with HTTP 401

## api.permissions.v1.function.test_helpers.function.get_function_by_name module

`api.permissions.v1.function.test_helpers.function.get_function_by_name.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/permissions/v1/function/w+, respond with HTTP 403

`api.permissions.v1.function.test_helpers.function.get_function_by_name.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/permissions/v1/function/w+, respond with HTTP 404

`api.permissions.v1.function.test_helpers.function.get_function_by_name.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/permissions/v1/function/w+, respond with HTTP 200

`api.permissions.v1.function.test_helpers.function.get_function_by_name.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/permissions/v1/function/w+, respond with HTTP 401

## Module contents